@@ -15,8 +15,7 @@ from dposlib.ark.tx import serialize, Transaction
 from ledgerblue.comm import getDongle
 from ledgerblue.commException import CommException
 
-PACK = (lambda f, v: struct.pack(f, v)) if dposlib.PY3 else \
-       (lambda f, v: bytes(struct.pack(f, v)))
+PACK = (lambda f, v: struct.pack(f, v))
 
 # Limits
 chunkSize = 255
@@ -176,7 +175,7 @@ def signMessage(msg, path=None, schnorr=True, debug=False):
     Compute schnorr or ecdsa signature of msg according to derivation path.
 
     Args:
-        msg (str or bytes): transaction as dictionary.
+        msg (str or bytes): message to sign.
         path (str): derivation path.
         schnorr (bool): use schnorr signature if True else ecdsa.
         debug (bool): flag to activate debug messages from ledger key.
