@@ -3,16 +3,13 @@
 import re
 import json
 import dposlib
-
+from io import BytesIO
 from collections import OrderedDict
-from dposlib import BytesIO
+
 from dposlib import cfg
 from dposlib.ark import slots, serde
 from dposlib.util.bin import hexlify, unhexlify, pack, pack_bytes, checkAddress
 
-if dposlib.PY3:
-    long = int
-
 
 def setSenderPublicKey(cls, publicKey):
     # load information from blockchain
@@ -58,20 +55,28 @@ def deleteSenderPublicKey(cls):
 
 
 def setFees(cls, value=None):
-    fmult = Transaction.FMULT
-    feesl = Transaction.FEESL
-
-    # manualy set fees
-    if isinstance(value, (float, int, long)):
+    # get name of the transaction according to typeGroup and type
+    name = \
+        dposlib.core.GETNAME.get(cls["typeGroup"], 1).get(cls["type"], 0)(cls)
+    # get static fee value
+    staticValue = int(
+        getattr(cfg, "fees", {}).get("staticFees", {})
+        .get(name, 10000000)
+    )
+    # manualy set fees if a scalar value is given
+    if isinstance(value, (float, int)):
         value = int(value)
-
     else:
-        # try to use fee multiplier
+        # get a copy of Transactions object parameters
+        fmult = Transaction.FMULT
+        feesl = Transaction.FEESL
+        # try to use fee multiplier. Fee multiplier have to be given as integer
+        # string ie: "1000"
         try:
             fmult = int(value)
-        # use fee statistics or static fees
+        # if excpetion, use fee statistics or static fees
         except (ValueError, TypeError):
-            fmult = Transaction.FMULT
+            # fmult = Transaction.FMULT
             if isinstance(value, str):
                 feesl = value if value[:3] in ["min", "avg", "max"] else feesl
         else:
@@ -80,36 +85,27 @@ def setFees(cls, value=None):
         if feesl is None:
             # use static fees
             if fmult is None:
-                value = int(
-                    getattr(cfg, "fees", {}).get("staticFees", {})
-                    .get(dposlib.core.TRANSACTIONS[cls["type"]], 10000000)
-                )
+                value = staticValue
             # compute dynamic fees
             # https://github.com/ArkEcosystem/AIPs/blob/master/AIPS/aip-16.md
             else:
-                typ_ = cls.get("type", 0)
                 version = cls.get("version", 0x01)
-
                 vendorField = cls.get("vendorField", "")
                 lenVF = len(
                     vendorField if isinstance(vendorField, bytes) else
                     vendorField.encode("utf-8")
                 )
-
                 value = int(
-                    cfg.doffsets.get(dposlib.core.TRANSACTIONS[typ_], 100) +
+                    cfg.doffsets.get(name, 100) +
                     55 + (4 if version >= 0x02 else 0) +
                     lenVF + len(serde.serializePayload(cls))
                 ) * fmult
         # use fee statistics
         else:
-            name = dposlib.core.GETNAME[cls["typeGroup"]][cls["type"]](cls)
-            value = int(
-                cfg.feestats[str(cls["typeGroup"])][name][feesl[:3]]
-            )
+            value = int(cfg.feestats[str(cls["typeGroup"])][name][feesl[:3]])
 
     cls._reset()
-    dict.__setitem__(cls, "fee", value)
+    dict.__setitem__(cls, "fee", value or staticValue)
 
 
 def setFeeIncluded(cls):
@@ -197,7 +193,8 @@ def serialize(tx, **options):
         pack_bytes(buf, b"".join([unhexlify(sig) for sig in tx["signatures"]]))
 
     # id part
-    pack_bytes(buf, unhexlify(tx.get("id", "")))
+    if "id" in tx:
+        pack_bytes(buf, unhexlify(tx.get("id", "")))
 
     result = buf.getvalue()
     buf.close()
@@ -214,6 +211,18 @@ class Transaction(dict):
     FEESL = None
 
     # custom properties definitions
+    secret = property(
+        lambda cls: hasattr(cls, "_privateKey"),
+        lambda cls, passphrase: cls.link(passphrase, None),
+        None,
+        ""
+    )
+    secondSecret = property(
+        lambda cls: hasattr(cls, "_secondPrivateKey"),
+        lambda cls, passphrase: cls.link(None, passphrase),
+        None,
+        ""
+    )
     datetime = property(
         lambda cls: slots.getRealTime(cls["timestamp"]),
         None,
@@ -287,7 +296,7 @@ class Transaction(dict):
             value (str or int): constant or fee multiplier.
         """
         if hasattr(cfg, "doffsets"):
-            if isinstance(value, (int, float, long)):
+            if isinstance(value, (int, float)):
                 Transaction.FMULT = int(value)
                 Transaction.FEESL = None
             elif value in ["maxFee", "avgFee", "minFee"]:
@@ -303,7 +312,6 @@ class Transaction(dict):
     setDynamicFee = useDynamicFee
     useStaticFee = setStaticFee = lambda self: self.useDynamicFee(None)
 
-    # private definitions
     def _setitem(self, item, value):
         try:
             cast = dposlib.core.TYPING[item]
@@ -328,7 +336,6 @@ class Transaction(dict):
         self.FMULT = kwargs.pop("FMULT", Transaction.FMULT)
         # initialize a void dict
         dict.__init__(self)
-        # if blockchain package loaded merge all elements else return void dict
         data = dict(*args, **kwargs)
         last_to_be_set = [
             (k, data.pop(k, None)) for k in [
@@ -349,20 +356,21 @@ class Transaction(dict):
             (k, v) for k, v in list(data.items()) + last_to_be_set
             if v is not None
         ]:
-            self[key] = value
+            try:
+                self[key] = value
+            except Exception:
+                pass
 
     def __setitem__(self, item, value):
-        if item == "secret":
-            self.link(value)
-        elif item == "secondSecret":
-            self.link(None, value)
+        try:
+            # access item as property ?
+            dict.__getattribute__(self, item)
+        except AttributeError:
+            # set value using _setitem filter
+            self._setitem(item, value)
         else:
-            try:
-                dict.__getattribute__(self, item)
-            except AttributeError:
-                self._setitem(item, value)
-            else:
-                object.__setattr__(self, item, value)
+            # set property
+            object.__setattr__(self, item, value)
     __setattr__ = __setitem__
 
     def __getattr__(self, attr):
@@ -379,7 +387,12 @@ class Transaction(dict):
         )
 
     def __repr__(self):
-        return "<Blockchain transaction type %(typeGroup)s:%(type)s>" % self
+        return (
+            "<Blockchain transaction type %(typeGroup)s:%(type)s" +
+            "\n  amount=%(amount)r" +
+            "\n  vendorField=%(vendorField)r" +
+            "\n  asset=%(asset)r\n>"
+        ) % self
 
     def link(self, secret=None, secondSecret=None):
         """
@@ -400,6 +413,9 @@ class Transaction(dict):
                 self._secondPrivateKey = keys["privateKey"]
 
     def unlink(self):
+        """
+        Remove all ownership parameters. The transaction return to orphan mode.
+        """
         try:
             deleteSenderPublicKey(self)
             del self._privateKey
@@ -408,6 +424,12 @@ class Transaction(dict):
             pass
 
     def touch(self):
+        """
+        Update inner parameters using blockchain connection.
+        """
+        self._reset()
+        self.pop("nonce", False)
+        self.pop("timestamp", False)
         if hasattr(self, "_publicKey"):
             self.senderPublicKey = self._publicKey
 
@@ -426,8 +448,8 @@ class Transaction(dict):
                     len(self.get("signature", []))
                 if missings:
                     raise Exception("owner signature missing (%d)" % missings)
-            self["signature"] = dposlib.core.crypto.getSignatureFromBytes(
-                serialize(self), self._privateKey
+            self["signature"] = dposlib.core.crypto.getSignature(
+               self, self._privateKey
             )
         else:
             raise Exception("orphan transaction can not sign itsef")
@@ -436,14 +458,15 @@ class Transaction(dict):
     def signSign(self):
         """
         Generate the `signSignature` field. Transaction have to be signed and
-        second  private key have to be set first.
+        second private key have to be set first.
         """
         if "signature" in self:  # or "signatures" in self ?
+            self.pop("id", False)
             try:
-                self["signSignature"] = \
-                    dposlib.core.crypto.getSignatureFromBytes(
-                        serialize(self), self._secondPrivateKey
-                    )
+                self["signSignature"] = dposlib.core.crypto.getSignature(
+                    self, self._secondPrivateKey,
+                    exclude_second_sig=True,
+                )
             except AttributeError:
                 raise Exception("no second private Key available")
         else:
@@ -453,9 +476,7 @@ class Transaction(dict):
     def signWithSecret(self, secret):
         """
         Generate the `signature` field using passphrase. The associated
-        public and private keys are stored till [`dposlib.ark.unlink`](
-            ark.md#unlink
-        ) is called.
+        public and private keys are stored till `dposlib.ark.unlink` is called.
 
         Args:
             secret (`str`): passphrase.
@@ -467,7 +488,7 @@ class Transaction(dict):
         """
         Generate the `signSignature` field using second passphrase. The
         associated second public and private keys are stored till
-        [`dposlib.ark.unlink`](ark.md#unlink) is called.
+        `dposlib.ark.unlink` is called.
 
         Args:
             secondSecret (`str`): second passphrase.
@@ -490,7 +511,7 @@ class Transaction(dict):
     def signWithKeys(self, publicKey, privateKey):
         """
         Generate the `signature` field using public and private keys. They
-        are stored till [`dposlib.ark.unlink`](ark.md#unlink) is called.
+        are stored till `dposlib.ark.unlink` is called.
 
         Args:
             publicKey (str): public key as hex string.
@@ -504,7 +525,7 @@ class Transaction(dict):
     def signSignWithKey(self, secondPrivateKey):
         """
         Generate the `signSignature` field using second private key. It is
-        stored till [`dposlib.ark.unlink`](ark.md#unlink) is called.
+        stored till `dposlib.ark.unlink` is called.
 
         Args:
             secondPrivateKey (`str`): second private key as hex string.
@@ -546,6 +567,10 @@ class Transaction(dict):
             raise ValueError("public key %s not allowed here" % publicKey)
 
     def appendMultiSignature(self, publicKey, signature):
+        """
+        Manage the place of signature in signatures list for multisignature
+        wallet transaction or registration.
+        """
         # if type 4 find index in asset
         if self["type"] == 4:
             index = self.asset["multiSignature"]["publicKeys"].index(
@@ -575,6 +600,7 @@ class Transaction(dict):
             elif self._secondPublicKey:
                 if "signSignature" not in self:
                     raise Exception("second signature is missing")
+            dict.pop(self, "id", False)
             self["id"] = dposlib.core.crypto.getIdFromBytes(
                 serialize(self, exclude_multi_sig=False)
             )
@@ -590,8 +616,7 @@ class Transaction(dict):
             secret (str): passphrase.
             secondSecret (str): second passphrase.
             fee (int): manually set fee value in `arktoshi`.
-            fee_included (bool): see
-                [`dposlib.ark.tx.Transaction.feeIncluded`](ark.md#feeincluded).
+            fee_included (bool): see `dposlib.ark.tx.Transaction.feeIncluded`.
         """
         self.link(secret, secondSecret)
         # automatically set fees if needed
