@@ -1,15 +1,11 @@
 # -*- coding: utf-8 -*-
 
-"""
-Binary data manipulation that perform samely on python 2.x and 3.x.
-"""
-
 import re
 import struct
 import binascii
 import base58
 
-from dposlib import PY3
+# from dposlib import PY3
 
 HEX = re.compile("[0-9a-fA-F]")
 BHEX = re.compile(b"[0-9a-fA-F]")
@@ -22,7 +18,7 @@ def intasb(i):
 
 def basint(e):
     # byte as int conversion
-    return struct.pack("B", e)
+    return struct.unpack("B", e)[0]
 
 
 def unpack(fmt, fileobj):
@@ -46,7 +42,7 @@ def pack_bytes(f, v):
 
 
 def hexlify(data):
-    if PY3 and isinstance(data, str):
+    if isinstance(data, str):
         if HEX.match(data):
             return data
         else:
@@ -56,7 +52,7 @@ def hexlify(data):
 
 
 def unhexlify(data):
-    if PY3 and isinstance(data, bytes):
+    if isinstance(data, bytes):
         if BHEX.match(data):
             data = data.decode()
         else:
@@ -68,8 +64,5 @@ def unhexlify(data):
 
 
 def checkAddress(address):
-    if base58.b58decode_check(
-        address.encode("utf-8")
-        if not PY3 and not isinstance(address, bytes) else address
-    ):
+    if base58.b58decode_check(address):
         return address
