@@ -1,16 +1,17 @@
 # -*- coding: utf-8 -*-
 
+import re
 import os
 import io
 import json
 
-from dposlib import PY3
+# from dposlib import PY3
 
 
 def loadJson(path):
     """Load JSON data from path"""
     if os.path.exists(path):
-        with io.open(path, encoding="utf-8") as in_:
+        with io.open(path, "r", encoding="utf-8") as in_:
             data = json.load(in_)
     else:
         data = {}
@@ -28,10 +29,7 @@ def dumpJson(data, path):
         os.makedirs(os.path.dirname(path))
     except Exception:
         pass
-    with io.open(
-        path, "w" if PY3 else "wb",
-        **({"encoding": "utf-8"} if PY3 else {})
-    ) as out:
+    with io.open(path, "w", encoding="utf-8") as out:
         json.dump(data, out, indent=4)
     try:
         out.close()
